@@ -46,8 +46,7 @@ def interactive_plot(
     xlim="stretch",
     ylim="stretch",
     force_ipywidgets=False,
-    play_buttons=False,
-    play_button_pos="right",
+    play_buttons=None,
     controls=None,
     display_controls=True,
     **kwargs,
@@ -91,12 +90,15 @@ def interactive_plot(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
-    play_buttons : bool or dict, optional
+    play_buttons : bool or str or dict, optional
         Whether to attach an ipywidgets.Play widget to any sliders that get created.
         If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
         want to attach play buttons too.
-    play_button_pos : str, or dict, or list(str)
-        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
+            - None: no sliders
+            - True: sliders on the lft
+            - False: no sliders
+            - 'left': sliders on the left
+            - 'right': sliders on the right
     controls : mpl_interactions.controller.Controls
         An existing controls object if you want to tie multiple plot elements to the same set of
         controls
@@ -183,7 +185,7 @@ def interactive_plot(
     fig, ax = gogogo_figure(ipympl, ax=ax)
     slider_formats = create_slider_format_dict(slider_formats)
     controls, params = gogogo_controls(
-        kwargs, controls, display_controls, slider_formats, play_buttons, play_button_pos
+        kwargs, controls, display_controls, slider_formats, play_buttons
     )
 
     def update(params, indices, cache):
@@ -334,7 +336,6 @@ def interactive_hist(
     title=None,
     force_ipywidgets=False,
     play_buttons=False,
-    play_button_pos="right",
     controls=None,
     display_controls=True,
     **kwargs,
@@ -367,12 +368,15 @@ def interactive_hist(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
-    play_buttons : bool or dict, optional
+    play_buttons : bool or str or dict, optional
         Whether to attach an ipywidgets.Play widget to any sliders that get created.
         If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
         want to attach play buttons too.
-    play_button_pos : str, or dict, or list(str)
-        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
+            - None: no sliders
+            - True: sliders on the lft
+            - False: no sliders
+            - 'left': sliders on the left
+            - 'right': sliders on the right
     controls : mpl_interactions.controller.Controls
         An existing controls object if you want to tie multiple plot elements to the same set of
         controls
@@ -406,7 +410,7 @@ def interactive_hist(
     use_ipywidgets = ipympl or force_ipywidgets
     slider_formats = create_slider_format_dict(slider_formats)
     controls, params = gogogo_controls(
-        kwargs, controls, display_controls, slider_formats, play_buttons, play_button_pos
+        kwargs, controls, display_controls, slider_formats, play_buttons
     )
     pc = PatchCollection([])
     ax.add_collection(pc, autolim=True)
@@ -454,7 +458,6 @@ def interactive_scatter(
     ylim="stretch",
     force_ipywidgets=False,
     play_buttons=False,
-    play_button_pos="right",
     controls=None,
     display_controls=True,
     **kwargs,
@@ -501,13 +504,15 @@ def interactive_scatter(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
-    play_buttons : bool or dict or list(str), optional
+    play_buttons : bool or str or dict, optional
         Whether to attach an ipywidgets.Play widget to any sliders that get created.
         If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
-        want to attach play buttons too. If a list of strings use the names of the parameters that
-        you want to have sliders
-    play_button_pos : str, or dict, or list(str)
-        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
+        want to attach play buttons too.
+            - None: no sliders
+            - True: sliders on the lft
+            - False: no sliders
+            - 'left': sliders on the left
+            - 'right': sliders on the right
     controls : mpl_interactions.controller.Controls
         An existing controls object if you want to tie multiple plot elements to the same set of
         controls
@@ -534,7 +539,7 @@ def interactive_scatter(
     use_ipywidgets = ipympl or force_ipywidgets
     slider_formats = create_slider_format_dict(slider_formats)
     controls, params = gogogo_controls(
-        kwargs, controls, display_controls, slider_formats, play_buttons, play_button_pos
+        kwargs, controls, display_controls, slider_formats, play_buttons
     )
 
     def update(params, indices, cache):
@@ -653,7 +658,6 @@ def interactive_imshow(
     title=None,
     force_ipywidgets=False,
     play_buttons=False,
-    play_button_pos="right",
     controls=None,
     display_controls=True,
     **kwargs,
@@ -695,13 +699,20 @@ def interactive_imshow(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
-    play_buttons : bool or dict or list(str), optional
+    play_buttons : bool or str or dict, optional
         Whether to attach an ipywidgets.Play widget to any sliders that get created.
         If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
-        want to attach play buttons too. If a list of strings use the names of the parameters that
-        you want to have sliders
-    play_button_pos : str, or dict, or list(str)
-        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
+        want to attach play buttons too.
+            - None: no sliders
+            - True: sliders on the lft
+            - False: no sliders
+            - 'left': sliders on the left
+            - 'right': sliders on the right
+    controls : mpl_interactions.controller.Controls
+        An existing controls object if you want to tie multiple plot elements to the same set of
+        controls
+    display_controls : boolean
+        Whether the controls should display themselve on creation. Ignored if controls is specified.
 
     returns
     -------
@@ -713,7 +724,7 @@ def interactive_imshow(
     slider_formats = create_slider_format_dict(slider_formats)
 
     controls, params = gogogo_controls(
-        kwargs, controls, display_controls, slider_formats, play_buttons, play_button_pos
+        kwargs, controls, display_controls, slider_formats, play_buttons
     )
 
     def update(params, indices, cache):
@@ -770,7 +781,6 @@ def interactive_axhline(
     title=None,
     force_ipywidgets=False,
     play_buttons=False,
-    play_button_pos="right",
     controls=None,
     display_controls=True,
     **kwargs,
@@ -796,12 +806,15 @@ def interactive_axhline(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
-    play_buttons : bool or dict, optional
+    play_buttons : bool or str or dict, optional
         Whether to attach an ipywidgets.Play widget to any sliders that get created.
         If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
         want to attach play buttons too.
-    play_button_pos : str, or dict, or list(str)
-        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
+            - None: no sliders
+            - True: sliders on the lft
+            - False: no sliders
+            - 'left': sliders on the left
+            - 'right': sliders on the right
     controls : mpl_interactions.controller.Controls
         An existing controls object if you want to tie multiple plot elements to the same set of
         controls
@@ -818,7 +831,7 @@ def interactive_axhline(
     slider_formats = create_slider_format_dict(slider_formats)
 
     controls, params = gogogo_controls(
-        kwargs, controls, display_controls, slider_formats, play_buttons, play_button_pos
+        kwargs, controls, display_controls, slider_formats, play_buttons
     )
 
     def update(params, indices, cache):
@@ -850,7 +863,6 @@ def interactive_axvline(
     title=None,
     force_ipywidgets=False,
     play_buttons=False,
-    play_button_pos="right",
     controls=None,
     display_controls=True,
     **kwargs,
@@ -876,12 +888,15 @@ def interactive_axvline(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
-    play_buttons : bool or dict, optional
+    play_buttons : bool or str or dict, optional
         Whether to attach an ipywidgets.Play widget to any sliders that get created.
         If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
         want to attach play buttons too.
-    play_button_pos : str, or dict, or list(str)
-        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
+            - None: no sliders
+            - True: sliders on the lft
+            - False: no sliders
+            - 'left': sliders on the left
+            - 'right': sliders on the right
     controls : mpl_interactions.controller.Controls
         An existing controls object if you want to tie multiple plot elements to the same set of
         controls
@@ -898,7 +913,7 @@ def interactive_axvline(
     slider_formats = create_slider_format_dict(slider_formats)
 
     controls, params = gogogo_controls(
-        kwargs, controls, display_controls, slider_formats, play_buttons, play_button_pos
+        kwargs, controls, display_controls, slider_formats, play_buttons
     )
 
     def update(params, indices, cache):
